Allows for compile-time access to various property fields, as most of the usefule methods on Joda-Time Properties do not implement a common interface.
Only properties of the immutable dates/instants/partials/periods are supported.
Allows for compile-time access to various property fields, as most of the usefule methods on Joda-Time Properties do not implement a common interface. Only properties of the immutable dates/instants/partials/periods are supported.
(max-value p)The maximum value of a property.
The maximum value of a property.
(min-value p)The minimum value of a property.
The minimum value of a property.
(value p)Value of this property.
Value of this property.
(with-max-value p)Instant, partial or a period with the value of the property set to the
max-value.
Instant, partial or a period with the value of the property set to the `max-value`.
(with-min-value p)Instant, partial or a period with the value of the property set to the
min-value.
Instant, partial or a period with the value of the property set to the `min-value`.
(with-value p v)Instant, partial or a period with the property set to the provided value.
Instant, partial or a period with the property set to the provided value.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |